//	Release Version:	$ ODF 1 $
//	Copyright:	(c) 1993 - 1996 by Apple Computer, Inc., all rights reserved.

//================================================================================
#ifndef PART_H
#include "Part.h"
#endif

#ifndef DEFINES_K
#include "Defines.k"
#endif

#ifndef BINDING_K
#include "Binding.k"
#endif

#ifndef FRAME_H
#include "Frame.h"
#endif

// ----- Framework Layer -----
#ifndef FWPRESEN_H
#include "FWPresen.h"		// FW_CPresentation
#endif

#ifndef FWUTIL_H
#include "FWUtil.h"			// FW_Beep()
#endif

#ifndef FWABOUT_H
#include "FWAbout.h"		//::FW_About()
#endif

// ----- OS Layer -----
#ifndef   FWRESFIL_H
#include "FWResFil.h"		// FW_CResourceFile
#endif

#ifndef FWMENU_H
#include "FWMenu.h"			// FW_CMenuBar, FW_CPullDownMenu
#endif

#ifndef FWCFMRES_H
#include "FWCFMRes.h"		// FW_CSharedLibraryResourceFile
#endif

#ifndef FWEVENT_H
#include "FWEvent.h"		// FW_CMenuEvent
#endif

//==============================================================================
#ifdef FW_BUILD_WIN16
	extern HANDLE far gWinInstance;		// Initialized by LibMain
#endif

#ifdef FW_BUILD_MAC
#pragma segment Mnu
#endif

FW_DEFINE_AUTO(CMnuPart)
//==============================================================================
CMnuPart::CMnuPart(ODPart* odPart)
  :	FW_CPart(odPart, FW_gInstance, kPartInfoID),
	fPresentation(NULL)
{
}

//--------------------------------------------------------------------------------
CMnuPart::~CMnuPart()
{
}

//--------------------------------------------------------------------------------
void 
CMnuPart::Initialize(Environment* ev)	// Override
{
	FW_CPart::Initialize(ev);
	const ODType kMainPresentation = "Apple:Presentation:Mnu";
	fPresentation = RegisterPresentation(ev, kMainPresentation, true, NULL);
	FW_CSharedLibraryResourceFile resFile(ev);
	GetMenuBar(ev)->InitializeFromResource(ev, kMenuBarID);
}

//--------------------------------------------------------------------------------
FW_Boolean 
CMnuPart::DoAdjustMenus(Environment* ev, FW_CMenuBar* menuBar, 
									 FW_Boolean hasMenuFocus,
									 FW_Boolean isRoot)	// Override
{
	if (hasMenuFocus) {	
		menuBar->EnableCommand(ev, cItemOneCommand, true);
		menuBar->EnableCommand(ev, cItemTwoCommand, true);
	}
	return FALSE;
}

//--------------------------------------------------------------------------------
FW_Boolean 
CMnuPart::DoMenu(Environment* ev, const FW_CMenuEvent& theMenuEvent)	// Override
{
	FW_Boolean menuHandled = true;
	ODCommandID commandID = theMenuEvent.GetCommandID(ev);
	
	switch (commandID)
	{
		case kODCommandAbout:
			::FW_About(ev, this, kAbout);
			break;

		case cItemOneCommand:
			fPresentation->Invalidate(ev);
			break;

		case cItemTwoCommand:
			fPresentation->Invalidate(ev);
			break;

		default:
			menuHandled = false;
	}
	return menuHandled;
}

//--------------------------------------------------------------------------------
FW_CFrame* 
CMnuPart::NewFrame(Environment* ev, ODFrame* odFrame,
						FW_CPresentation* presentation, FW_Boolean fromStorage)	// Override
{
	FW_UNUSED(presentation);
	FW_UNUSED(fromStorage);
	return FW_NEW(CMnuFrame, (ev, odFrame, presentation, this) );
}

//------------------------------------------------------------------------------
FW_CContent* 
CMnuPart::NewPartContent(Environment* ev)
{
	return NULL;
}

